@@ -13,7 +13,7 @@ This will raise an AssertionError if the two matrix objects are not
 equal, including information regarding what exactly failed to match.
 
 Note that this functionality could not be provided using comparison
-methods on all objects as comparison opertors only return Booleans and
+methods on all objects as comparison operators only return Booleans and
 thus would not supply any information regarding *why* two elements are
 considered different.
 """
@@ -254,7 +254,8 @@ class Comparison(ComparisonInterface):
     @classmethod
     def bounds_check(cls, el1, el2, msg=None):
         if el1.bounds.lbrt() != el2.bounds.lbrt():
-            raise cls.failureException("BoundingBoxes are mismatched.")
+            raise cls.failureException("BoundingBoxes are mismatched: %s != %s."
+                                       % (el1.bounds.lbrt(), el2.bounds.lbrt()))
 
 
     #=======================================#
