@@ -3,8 +3,9 @@ from bokeh.models import CustomJS
 
 from ...core import OrderedDict
 from ...streams import (Stream, PointerXY, RangeXY, Selection1D, RangeX,
-                        RangeY, PointerX, PointerY, Bounds, Tap,
-                        DoubleTap, MouseEnter, MouseLeave, PlotSize)
+                        RangeY, PointerX, PointerY, Bounds, BoundsX, BoundsY,
+                        Tap, SingleTap, DoubleTap, MouseEnter, MouseLeave,
+                        PlotSize, Draw)
 from ...streams import PositionX, PositionY, PositionXY # Deprecated: remove in 2.0
 from ..comms import JupyterCommJS
 from .util import bokeh_version
@@ -519,7 +520,22 @@ class PointerXYCallback(Callback):
 
     attributes = {'x': 'cb_obj.x', 'y': 'cb_obj.y'}
     models = ['plot']
+    extra_models= ['x_range', 'y_range']
+
     on_events = ['mousemove']
+    # Clip x and y values to available axis range
+    code = """
+           if (x_range.type.endsWith('Range1d')) {
+             if (cb_obj.x < x_range.start) {
+               data['x'] = x_range.start }
+             else if (cb_obj.x > x_range.end) {
+               data['x'] = x_range.end }}
+           if (y_range.type.endsWith('Range1d')) {
+             if (cb_obj.y < y_range.start) {
+               data['y'] = y_range.start }
+             else if (cb_obj.y > y_range.end) {
+               data['y'] = y_range.end }}
+           """
 
 
 class PointerXCallback(PointerXYCallback):
@@ -528,7 +544,14 @@ class PointerXCallback(PointerXYCallback):
     """
 
     attributes = {'x': 'cb_obj.x'}
-
+    extra_models= ['x_range']
+    code = """
+           if (x_range.type.endsWith('Range1d')) {
+             if (cb_obj.x < x_range.start) {
+               data['x'] = x_range.start }
+             else if (cb_obj.x > x_range.end) {
+               data['x'] = x_range.end }}
+           """
 
 class PointerYCallback(PointerXYCallback):
     """
@@ -536,11 +559,47 @@ class PointerYCallback(PointerXYCallback):
     """
 
     attributes = {'y': 'cb_obj.y'}
+    extra_models= ['y_range']
+    code = """
+           if (y_range.type.endsWith('Range1d')) {
+             if (cb_obj.y < y_range.start) {
+               data['y'] = y_range.start }
+             else if (cb_obj.y > y_range.end) {
+               data['y'] = y_range.end }}
+           """
+
+class DrawCallback(PointerXYCallback):
+    on_events = ['pan', 'panstart', 'panend']
+    models = ['plot']
+    extra_models=['pan', 'box_zoom', 'x_range', 'y_range']
+    skip = ['pan && pan.attributes.active', 'box_zoom && box_zoom.attributes.active']
+    attributes = {'x': 'cb_obj.x', 'y': 'cb_obj.y', 'event': 'cb_obj.event_name'}
+
+    def __init__(self, *args, **kwargs):
+        self.stroke_count = 0
+        super(DrawCallback, self).__init__(*args, **kwargs)
+
+    def _process_msg(self, msg):
+        event = msg.pop('event')
+        if event == 'panend':
+            self.stroke_count += 1
+        return dict(msg, stroke_count=self.stroke_count)
 
 
 class TapCallback(PointerXYCallback):
     """
     Returns the mouse x/y-position on tap event.
+
+    Note: As of bokeh 0.12.5, there is no way to distinguish the
+    individual tap events within a doubletap event.
+    """
+
+    on_events = ['tap', 'doubletap']
+
+
+class SingleTapCallback(PointerXYCallback):
+    """
+    Returns the mouse x/y-position on tap event.
     """
 
     on_events = ['tap']
@@ -643,17 +702,18 @@ class PlotSizeCallback(Callback):
             return {}
 
 
-
 class BoundsCallback(Callback):
     """
     Returns the bounds of a box_select tool.
     """
-
-    attributes = {'x0': 'cb_data.geometry.x0',
-                  'x1': 'cb_data.geometry.x1',
-                  'y0': 'cb_data.geometry.y0',
-                  'y1': 'cb_data.geometry.y1'}
-    models = ['box_select']
+    attributes = {'x0': 'cb_obj.geometry.x0',
+                  'x1': 'cb_obj.geometry.x1',
+                  'y0': 'cb_obj.geometry.y0',
+                  'y1': 'cb_obj.geometry.y1'}
+    models = ['plot']
+    extra_models = ['box_select']
+    on_events = ['selectiongeometry']
+    skip = ["!box_select || !box_select.active"]
 
     def _process_msg(self, msg):
         if all(c in msg for c in ['x0', 'y0', 'x1', 'y1']):
@@ -662,6 +722,42 @@ class BoundsCallback(Callback):
             return {}
 
 
+class BoundsXCallback(Callback):
+    """
+    Returns the bounds of a xbox_select tool.
+    """
+
+    attributes = {'x0': 'cb_obj.geometry.x0', 'x1': 'cb_obj.geometry.x1'}
+    models = ['plot']
+    extra_models = ['xbox_select']
+    on_events = ['selectiongeometry']
+    skip = ["!xbox_select || !xbox_select.active"]
+
+    def _process_msg(self, msg):
+        if all(c in msg for c in ['x0', 'x1']):
+            return {'boundsx': (msg['x0'], msg['x1'])}
+        else:
+            return {}
+
+
+class BoundsYCallback(Callback):
+    """
+    Returns the bounds of a ybox_select tool.
+    """
+
+    attributes = {'y0': 'cb_obj.geometry.y0', 'y1': 'cb_obj.geometry.y1'}
+    models = ['plot']
+    extra_models = ['ybox_select']
+    on_events = ['selectiongeometry']
+    skip = ["!ybox_select || !ybox_select.active"]
+
+    def _process_msg(self, msg):
+        if all(c in msg for c in ['y0', 'y1']):
+            return {'boundsy': (msg['y0'], msg['y1'])}
+        else:
+            return {}
+
+
 class Selection1DCallback(Callback):
     """
     Returns the current selection on a ColumnDataSource.
@@ -680,10 +776,11 @@ class Selection1DCallback(Callback):
 
 callbacks = Stream._callbacks['bokeh']
 
-callbacks[PointerXY]  = PointerXYCallback
-callbacks[PointerX]   = PointerXCallback
-callbacks[PointerY]   = PointerYCallback
+callbacks[PointerXY]   = PointerXYCallback
+callbacks[PointerX]    = PointerXCallback
+callbacks[PointerY]    = PointerYCallback
 callbacks[Tap]         = TapCallback
+callbacks[SingleTap]   = SingleTapCallback
 callbacks[DoubleTap]   = DoubleTapCallback
 callbacks[MouseEnter]  = MouseEnterCallback
 callbacks[MouseLeave]  = MouseLeaveCallback
@@ -691,8 +788,11 @@ callbacks[RangeXY]     = RangeXYCallback
 callbacks[RangeX]      = RangeXCallback
 callbacks[RangeY]      = RangeYCallback
 callbacks[Bounds]      = BoundsCallback
+callbacks[BoundsX]     = BoundsXCallback
+callbacks[BoundsY]     = BoundsYCallback
 callbacks[Selection1D] = Selection1DCallback
 callbacks[PlotSize]    = PlotSizeCallback
+callbacks[Draw] = DrawCallback
 
 # Aliases for deprecated streams
 callbacks[PositionXY]  = PointerXYCallback
