@@ -7,6 +7,8 @@ from ...core import Dataset
 from ...element import ItemTable
 from ..plot import GenericElementPlot
 from .plot import BokehPlot
+from .util import bokeh_version
+
 
 class TablePlot(BokehPlot, GenericElementPlot):
 
@@ -17,6 +19,11 @@ class TablePlot(BokehPlot, GenericElementPlot):
     style_opts = ['row_headers', 'selectable', 'editable',
                   'sortable', 'fit_columns', 'width', 'height']
 
+    finalize_hooks = param.HookList(default=[], doc="""
+        Optional list of hooks called when finalizing a column.
+        The hook is passed the plot object and the displayed
+        object, and other plotting handles can be accessed via plot.handles.""")
+
     _update_handles = ['source', 'glyph']
 
     def __init__(self, element, plot=None, **params):
@@ -27,6 +34,17 @@ class TablePlot(BokehPlot, GenericElementPlot):
         self.callbacks = [] # Callback support on tables not implemented
 
 
+    def _execute_hooks(self, element):
+        """
+        Executes finalize hooks
+        """
+        for hook in self.finalize_hooks:
+            try:
+                hook(self, element)
+            except Exception as e:
+                self.warning("Plotting hook %r could not be applied:\n\n %s" % (hook, e))
+
+
     def get_data(self, element, ranges=None, empty=False):
         dims = element.dimensions()
         data = {d: np.array([]) if empty else element.dimension_values(d)
@@ -55,10 +73,13 @@ class TablePlot(BokehPlot, GenericElementPlot):
         dims = element.dimensions()
         columns = [TableColumn(field=d.name, title=d.pprint_label) for d in dims]
         properties = self.lookup_options(element, 'style')[self.cyclic_index]
+        if bokeh_version > '0.12.7':
+            properties['reorderable'] = False
         table = DataTable(source=source, columns=columns, height=self.height,
                           width=self.width, **properties)
         self.handles['plot'] = table
         self.handles['glyph_renderer'] = table
+        self._execute_hooks(element)
         self.drawn = True
 
         return table
