@@ -1,6 +1,7 @@
 import itertools, inspect, re, time
 from distutils.version import LooseVersion
 from collections import defaultdict
+import datetime as dt
 
 import numpy as np
 
@@ -30,9 +31,12 @@ try:
 except:
     Chart = type(None) # Create stub for isinstance check
 
+if bokeh_version > '0.12.7':
+    from bokeh.document.util import _event_for_attribute_change
+
 from ...core.options import abbreviated_exception
 from ...core.overlay import Overlay
-from ...core.util import basestring, unique_array, callable_name
+from ...core.util import basestring, unique_array, callable_name, pd, dt64_to_dt
 from ...core.spaces import get_nested_dmaps, DynamicMap
 
 from ..util import dim_axis_label, rgb2hex
@@ -381,9 +385,12 @@ def compute_static_patch(document, models):
         else:
             priority = float('inf')
         for key, val in obj['attributes'].items():
-            event = Document._event_for_attribute_change(references,
-                                                         obj, key, val,
-                                                         value_refs)
+            if bokeh_version > '0.12.7':
+                event = _event_for_attribute_change(references, obj, key, val, value_refs)
+            else:
+                event = Document._event_for_attribute_change(references,
+                                                             obj, key, val,
+                                                             value_refs)
             events.append((priority, event))
             update_types[obj['type']].append(key)
     events = [delete_refs(e, IGNORED_MODELS, ignored_attributes=IGNORED_ATTRIBUTES)
@@ -407,7 +414,7 @@ def delete_refs(obj, models=[], dropped_attributes=[], ignored_attributes=[]):
             return None
         new_obj = {}
         for k, v in list(obj.items()):
-            # Drop unneccessary attributes, i.e. those that do not
+            # Drop unnecessary attributes, i.e. those that do not
             # contain references to other objects.
             if k in dropped_attributes or (k == 'attributes' and not get_ids(v)):
                 continue
@@ -732,8 +739,6 @@ class periodic(object):
         return repr(self)
 
 
-
-
 def attach_periodic(plot):
     """
     Attaches plot refresh to all streams on the object.
@@ -742,3 +747,18 @@ def attach_periodic(plot):
         for dmap in get_nested_dmaps(dmap):
             dmap.periodic._periodic_util = periodic(plot.document)
     return plot.hmap.traverse(append_refresh, [DynamicMap])
+
+
+def date_to_integer(date):
+    """
+    Converts datetime types to bokeh's integer format.
+    """
+    if isinstance(date, np.datetime64):
+        date = dt64_to_dt(date)
+    elif pd and isinstance(date, pd.Timestamp):
+        date = date.to_pydatetime()
+    if isinstance(date, dt.datetime):
+        dt_int = time.mktime(date.timetuple())*1000
+    else:
+        raise ValueError('Datetime type not recognized')
+    return dt_int
