@@ -180,7 +180,7 @@ class MPLPlot(DimensionedPlot):
     def _subplot_label(self, axis):
         layout_num = self.layout_num if self.subplot else 1
         if self.sublabel_format and not self.adjoined and layout_num > 0:
-            from mpl_toolkits.axes_grid1.anchored_artists import AnchoredText
+            from matplotlib.offsetbox import AnchoredText
             labels = {}
             if '{Alpha}' in self.sublabel_format:
                 labels['Alpha'] = int_to_alpha(layout_num-1)
@@ -774,6 +774,8 @@ class LayoutPlot(GenericLayoutPlot, CompositePlot):
         for (r, c) in self.coords:
             # Get view at layout position and wrap in AdjointLayout
             _, view = layout_items.get((c, r) if self.transpose else (r, c), (None, None))
+            if isinstance(view, NdLayout):
+                raise SkipRendering("Cannot render NdLayout nested inside a Layout")
             layout_view = view if isinstance(view, AdjointLayout) else AdjointLayout([view])
             layouts[(r, c)] = layout_view
 
