@@ -24,7 +24,7 @@ def escape_vals(vals, escape_numerics=True):
     for v in vals:
         if not isnumeric(v):
             v = "'"+unicode(bytes_to_unicode(v))+"'"
-        elif isinstance(v, np.datetime64):
+        elif isinstance(v, (np.datetime64, np.timedelta64)):
             v = "'"+str(v)+"'"
         else:
             if v % 1 == 0:
@@ -241,8 +241,8 @@ class SelectionWidget(NdWidget):
     update the widget with a live IPython kernel.
 
     The widget supports all current HoloViews figure backends
-    including png, svg, mpld3 and nbagg output. To select nbagg
-    output, the SelectionWidget must not be set to embed.
+    including png, svg and nbagg output. To select nbagg output,
+    the SelectionWidget must not be set to embed.
 
     Just like the ScrubberWidget the data can be optionally saved
     to json and dynamically loaded from a server.
