@@ -184,7 +184,7 @@ class Stream(param.Parameterized):
         self._metadata = {}
 
         super(Stream, self).__init__(**params)
-        if source:
+        if source is not None:
             self.registry[id(source)].append(self)
 
 
@@ -502,7 +502,7 @@ class RangeY(LinkedStream):
       Range of the y-axis of a plot in data coordinates""")
 
 
-class Bounds(LinkedStream):
+class BoundsXY(LinkedStream):
     """
     A stream representing the bounds of a box selection as an
     tuple of the left, bottom, right and top coordinates.
@@ -513,6 +513,12 @@ class Bounds(LinkedStream):
         Bounds defined as (left, bottom, right, top) tuple.""")
 
 
+class Bounds(BoundsXY):
+
+    def __init__(self, *args, **kwargs):
+        self.warning('Bounds is deprecated use BoundsXY instead.')
+        super(Bounds, self).__init__(*args, **kwargs)
+
 class BoundsX(LinkedStream):
     """
     A stream representing the bounds of a box selection as an
